Skip to contents

Examples of interpolating irregular data, to illustrate the mechanics of various methods and some easy tools to run them.

Author

Maintainer: Michael Sumner mdsumner@gmail.com

Authors:

Other contributors:

  • Marcelino de la Cruz (wrote maybetin example function on R-Sig-Geo) [contributor]

  • Tomas Remenyi [contributor]