Superseded by grid_spec(), which returns a plain list rather than a
RasterLayer, and which takes its size as dimension = c(ncol, nrow).
Value
A guerrilla_grid, from grid_spec().
Superseded by grid_spec(), which returns a plain list rather than a
RasterLayer, and which takes its size as dimension = c(ncol, nrow).
A guerrilla_grid, from grid_spec().