The centre of every cell of grid, in cell order: left to right along the
top row, then the next row down.
Details
This is one call to vaster::xy_from_cell() with the grid's own first two
elements. It is the only thing the interpolation functions need to know
about the grid, which is why the grid can be a list.